@@ -12,13 +12,13 @@
 
 """Run a projects tests and load them into stestr."""
 
+import configparser
 import errno
 import functools
 import io
 import os
 import subprocess
 import sys
-import warnings
 
 from cliff import command
 import subunit
@@ -61,7 +61,7 @@ class Run(command.Command):
     """
 
     def get_parser(self, prog_name):
-        parser = super(Run, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument("filters", nargs="*", default=None,
                             help="A list of string regex filters to initially "
                             "apply on the test list. Tests that match any of "
@@ -79,11 +79,6 @@ class Run(command.Command):
                             "autodetects your CPU count.")
         parser.add_argument("--load-list", default=None,
                             help="Only run tests listed in the named file."),
-        parser.add_argument("--partial", action="store_true", default=False,
-                            help="DEPRECATED: Only some tests will be run. "
-                            "Implied by --failing. This option is deprecated "
-                            "and no longer does anything. It will be removed "
-                            "in the future")
         parser.add_argument("--subunit", action="store_true", default=False,
                             help="Display results in subunit format.")
         parser.add_argument("--until-failure", action="store_true",
@@ -101,36 +96,15 @@ class Run(command.Command):
                             dest='worker_path',
                             help="Optional path of a manual worker grouping "
                             "file to use for the run")
-        parser.add_argument('--blacklist-file', '-b',
-                            default=None, dest='blacklist_file',
-                            help='DEPRECATED: This option will soon be '
-                            'replaced by --exclude-list which is functionally '
-                            'equivalent. If this is specified at the same '
-                            'time as --exclude-list, this flag will be '
-                            'ignored and --exclude-list will be used.')
         parser.add_argument('--exclude-list', '-e',
                             default=None, dest='exclude_list',
                             help='Path to an exclusion list file, this file '
                             'contains a separate regex exclude on each '
                             'newline')
-        parser.add_argument('--whitelist-file', '-w',
-                            default=None, dest='whitelist_file',
-                            help='DEPRECATED: This option will soon be '
-                            'replaced by --include-list which is functionally '
-                            'equivalent. If this is specified at the same '
-                            'time as --include-list, this flag will be '
-                            'ignored and --include-list will be used.')
         parser.add_argument('--include-list', '-i',
                             default=None, dest='include_list',
                             help='Path to an inclusion list file, this file '
                             'contains a separate regex on each newline.')
-        parser.add_argument('--black-regex', '-B', default=None,
-                            dest='black_regex',
-                            help='DEPRECATED: This option will soon be '
-                            'replaced by --exclude-regex which is functionally'
-                            ' equivalent. If this is specified at the same '
-                            'time as --exclude-regex, this flag will be '
-                            'ignored and --exclude-regex will be used.')
         parser.add_argument('--exclude-regex', '-E', default=None,
                             dest='exclude_regex',
                             help='Test rejection regex. If a test cases name '
@@ -253,18 +227,18 @@ class Run(command.Command):
             stdout.write(msg)
             return 2
         result = run_command(
-            config=self.app_args.config, repo_type=self.app_args.repo_type,
+            config=self.app_args.config,
             repo_url=self.app_args.repo_url,
             test_path=self.app_args.test_path, top_dir=self.app_args.top_dir,
             group_regex=self.app_args.group_regex, failing=args.failing,
             serial=args.serial, concurrency=concurrency,
-            load_list=args.load_list, partial=args.partial,
+            load_list=args.load_list,
             subunit_out=args.subunit, until_failure=args.until_failure,
             analyze_isolation=args.analyze_isolation, isolated=args.isolated,
-            worker_path=args.worker_path, blacklist_file=args.blacklist_file,
-            exclude_list=args.exclude_list, whitelist_file=args.whitelist_file,
+            worker_path=args.worker_path,
+            exclude_list=args.exclude_list,
             include_list=args.include_list,
-            black_regex=args.black_regex, exclude_regex=args.exclude_regex,
+            exclude_regex=args.exclude_regex,
             no_discover=args.no_discover, random=random, combine=args.combine,
             filters=filters, pretty_out=pretty_out, color=color,
             stdout=stdout, abbreviate=abbreviate,
@@ -279,8 +253,7 @@ class Run(command.Command):
         if getattr(user_conf, 'run', False):
             user_slowest = user_conf.run.get('slowest', False)
         if args.slowest or user_slowest:
-            slowest.slowest(repo_type=self.app_args.repo_type,
-                            repo_url=self.app_args.repo_url)
+            slowest.slowest(repo_url=self.app_args.repo_url)
 
         return result
 
@@ -303,14 +276,29 @@ def _find_failing(repo):
     return ids
 
 
-def run_command(config='.stestr.conf', repo_type='file',
+def _load_list_and_filter(list_filename, filter_ids):
+    """Load list of IDs and optionally filter them by a list of ids."""
+    list_ids = []
+    set_ids = set()
+    # Should perhaps be text.. currently does its own decode.
+    with open(list_filename, 'rb') as list_file:
+        # Remove duplicates and filter out non failing tests when required
+        for test_id in parse_list(list_file.read()):
+            if test_id not in set_ids and (filter_ids is None or
+                                           test_id in filter_ids):
+                list_ids.append(test_id)
+                set_ids.add(test_id)
+    return list_ids
+
+
+def run_command(config='.stestr.conf',
                 repo_url=None, test_path=None, top_dir=None, group_regex=None,
                 failing=False, serial=False, concurrency=0, load_list=None,
-                partial=False, subunit_out=False, until_failure=False,
+                subunit_out=False, until_failure=False,
                 analyze_isolation=False, isolated=False, worker_path=None,
-                blacklist_file=None, exclude_list=None,
-                whitelist_file=None, include_list=None,
-                black_regex=None, exclude_regex=None, no_discover=False,
+                exclude_list=None,
+                include_list=None,
+                exclude_regex=None, no_discover=False,
                 random=False, combine=False, filters=None, pretty_out=True,
                 color=False, stdout=sys.stdout, abbreviate=False,
                 suppress_attachments=False, all_attachments=False,
@@ -323,8 +311,6 @@ def run_command(config='.stestr.conf', repo_type='file',
     printed to STDOUT and loaded into the repository.
 
     :param str config: The path to the stestr config file. Must be a string.
-    :param str repo_type: This is the type of repository to use. Valid choices
-        are 'file' and 'sql'.
     :param str repo_url: The url of the repository to use.
     :param str test_path: Set the test path to use for unittest discovery.
         If both this and the corresponding config file option are set, this
@@ -341,9 +327,6 @@ def run_command(config='.stestr.conf', repo_type='file',
         autodetects your CPU count and uses that.
     :param str load_list: The path to a list of test_ids. If specified only
         tests listed in the named file will be run.
-    :param bool partial: DEPRECATED: Only some tests will be run. Implied by
-        `--failing`. This flag is deprecated because and doesn't do anything
-        it will be removed in a future release.
     :param bool subunit_out: Display results in subunit format.
     :param bool until_failure: Repeat the run again and again until failure
         occurs.
@@ -352,19 +335,10 @@ def run_command(config='.stestr.conf', repo_type='file',
     :param bool isolated: Run each test id in a separate test runner.
     :param str worker_path: Optional path of a manual worker grouping file
         to use for the run.
-    :param str blacklist_file: DEPRECATED: soon to be replaced by the new
-        option exclude_list below. If this is specified at the same time as
-        exclude_list, this flag will be ignored and exclude_list will be used
     :param str exclude_list: Path to an exclusion list file, this file
         contains a separate regex exclude on each newline.
-    :param str whitelist_file: DEPRECATED: soon to be replaced by the new
-        option include_list below. If this is specified at the same time as
-        include_list, this flag will be ignored and include_list will be used
     :param str include_list: Path to a inclusion list file, this file
         contains a separate regex on each newline.
-    :param str black_regex: DEPRECATED: soon to be replaced by the new
-        option exclude_regex below. If this is specified at the same time as
-        exclude_regex, this flag will be ignored and exclude_regex will be used
     :param str exclude_regex: Test rejection regex. If a test cases name
         matches on re.search() operation, it will be removed from the final
         test list.
@@ -397,36 +371,31 @@ def run_command(config='.stestr.conf', repo_type='file',
         for failures.
     :rtype: int
     """
-    if partial:
-        warnings.warn('The partial flag is deprecated and has no effect '
-                      'anymore')
-    if blacklist_file is not None:
-        warnings.warn("The blacklist-file argument is deprecated and will be "
-                      "removed in a future release. Instead you should use "
-                      "exclude-list which is functionally equivalent",
-                      DeprecationWarning)
-    if whitelist_file is not None:
-        warnings.warn("The whitelist-file argument is deprecated and will be "
-                      "removed in a future release. Instead you should use "
-                      "include-list which is functionally equivalent",
-                      DeprecationWarning)
-    if black_regex is not None:
-        warnings.warn("The black-regex argument is deprecated and will be "
-                      "removed in a future release. Instead you should use "
-                      "exclude-regex which is functionally equivalent",
-                      DeprecationWarning)
     try:
-        repo = util.get_repo_open(repo_type, repo_url)
-    # If a repo is not found, and there a testr config exists just create it
+        repo = util.get_repo_open(repo_url=repo_url)
+    # If a repo is not found, and there a stestr config exists just create it
     except repository.RepositoryNotFound:
         if not os.path.isfile(config) and not test_path:
-            msg = ("No config file found and --test-path not specified. "
-                   "Either create or specify a .stestr.conf or use "
-                   "--test-path ")
-            stdout.write(msg)
-            exit(1)
+            # If there is no config and no test-path
+            if os.path.isfile('tox.ini'):
+                tox_conf = configparser.SafeConfigParser()
+                tox_conf.read('tox.ini')
+                if not tox_conf.has_section('stestr'):
+                    msg = ("No file found, --test-path not specified, and "
+                           "stestr section not found in tox.ini. Either "
+                           "create or specify a .stestr.conf, use "
+                           "--test-path, or add an stestr section to the "
+                           "tox.ini")
+                    stdout.write(msg)
+                    exit(1)
+            else:
+                msg = ("No config file found and --test-path not specified. "
+                       "Either create or specify a .stestr.conf or use "
+                       "--test-path ")
+                stdout.write(msg)
+                exit(1)
         try:
-            repo = util.get_repo_initialise(repo_type, repo_url)
+            repo = util.get_repo_initialise(repo_url=repo_url)
         except OSError as e:
             if e.errno != errno.EEXIST:
                 raise
@@ -481,7 +450,6 @@ def run_command(config='.stestr.conf', repo_type='file',
                                  stdout=subprocess.PIPE)))]
             return load.load(in_streams=run_proc,
                              subunit_out=subunit_out,
-                             repo_type=repo_type,
                              repo_url=repo_url, run_id=combine_id,
                              pretty_out=pretty_out,
                              color=color, stdout=stdout, abbreviate=abbreviate,
@@ -527,7 +495,6 @@ def run_command(config='.stestr.conf', repo_type='file',
         run_proc = [('subunit', stream)]
         return load.load(in_streams=run_proc,
                          subunit_out=subunit_out,
-                         repo_type=repo_type,
                          repo_url=repo_url, run_id=combine_id,
                          pretty_out=pretty_out,
                          color=color, stdout=stdout, abbreviate=abbreviate,
@@ -540,26 +507,21 @@ def run_command(config='.stestr.conf', repo_type='file',
     else:
         ids = None
     if load_list:
-        list_ids = set()
-        # Should perhaps be text.. currently does its own decode.
-        with open(load_list, 'rb') as list_file:
-            list_ids = set(parse_list(list_file.read()))
-        if ids is None:
-            # Use the supplied list verbatim
-            ids = list_ids
-        else:
-            # We have some already limited set of ids, just reduce to ids
-            # that are both failing and listed.
-            ids = list_ids.intersection(ids)
+        ids = _load_list_and_filter(load_list, ids)
 
-    conf = config_file.TestrConf(config)
+    if config and os.path.isfile(config):
+        conf = config_file.TestrConf(config)
+    elif os.path.isfile('tox.ini'):
+        conf = config_file.TestrConf('tox.ini', section='stestr')
+    else:
+        conf = config_file.TestrConf(config)
     if not analyze_isolation:
         cmd = conf.get_run_command(
-            ids, regexes=filters, group_regex=group_regex, repo_type=repo_type,
+            ids, regexes=filters, group_regex=group_regex,
             repo_url=repo_url, serial=serial, worker_path=worker_path,
-            concurrency=concurrency, blacklist_file=blacklist_file,
-            exclude_list=exclude_list, whitelist_file=whitelist_file,
-            include_list=include_list, black_regex=black_regex,
+            concurrency=concurrency,
+            exclude_list=exclude_list,
+            include_list=include_list,
             exclude_regex=exclude_regex,
             top_dir=top_dir, test_path=test_path, randomize=random)
         if isolated:
@@ -573,17 +535,17 @@ def run_command(config='.stestr.conf', repo_type='file',
                 # TODO(mtreinish): add regex
                 cmd = conf.get_run_command(
                     [test_id], filters, group_regex=group_regex,
-                    repo_type=repo_type, repo_url=repo_url, serial=serial,
+                    repo_url=repo_url, serial=serial,
                     worker_path=worker_path, concurrency=concurrency,
-                    blacklist_file=blacklist_file, exclude_list=exclude_list,
-                    whitelist_file=whitelist_file, include_list=include_list,
-                    black_regex=black_regex, exclude_regex=exclude_regex,
+                    exclude_list=exclude_list,
+                    include_list=include_list,
+                    exclude_regex=exclude_regex,
                     randomize=random, test_path=test_path, top_dir=top_dir)
 
                 run_result = _run_tests(
                     cmd, until_failure,
                     subunit_out=subunit_out, combine_id=combine_id,
-                    repo_type=repo_type, repo_url=repo_url,
+                    repo_url=repo_url,
                     pretty_out=pretty_out, color=color, abbreviate=abbreviate,
                     stdout=stdout, suppress_attachments=suppress_attachments,
                     all_attachments=all_attachments,
@@ -595,7 +557,6 @@ def run_command(config='.stestr.conf', repo_type='file',
             return _run_tests(cmd, until_failure,
                               subunit_out=subunit_out,
                               combine_id=combine_id,
-                              repo_type=repo_type,
                               repo_url=repo_url,
                               pretty_out=pretty_out,
                               color=color,
@@ -613,12 +574,12 @@ def run_command(config='.stestr.conf', repo_type='file',
         for test_id in ids:
             # TODO(mtrienish): Add regex
             cmd = conf.get_run_command(
-                [test_id], group_regex=group_regex, repo_type=repo_type,
+                [test_id], group_regex=group_regex,
                 repo_url=repo_url, serial=serial, worker_path=worker_path,
-                concurrency=concurrency, blacklist_file=blacklist_file,
-                exclude_list=exclude_list, whitelist_file=whitelist_file,
+                concurrency=concurrency,
+                exclude_list=exclude_list,
                 include_list=include_list,
-                black_regex=black_regex, exclude_regex=exclude_regex,
+                exclude_regex=exclude_regex,
                 randomize=random, test_path=test_path, top_dir=top_dir)
             if not _run_tests(cmd, until_failure):
                 # If the test was filtered, it won't have been run.
@@ -639,14 +600,14 @@ def run_command(config='.stestr.conf', repo_type='file',
             return 0
         bisect_runner = bisect_tests.IsolationAnalyzer(
             latest_run, conf, _run_tests, repo, test_path=test_path,
-            top_dir=top_dir, group_regex=group_regex, repo_type=repo_type,
+            top_dir=top_dir, group_regex=group_regex,
             repo_url=repo_url, serial=serial, concurrency=concurrency)
         # spurious-failure -> cause.
         return bisect_runner.bisect_tests(spurious_failures)
 
 
 def _run_tests(cmd, until_failure,
-               subunit_out=False, combine_id=None, repo_type='file',
+               subunit_out=False, combine_id=None,
                repo_url=None, pretty_out=True, color=False, stdout=sys.stdout,
                abbreviate=False, suppress_attachments=False,
                all_attachments=False, show_binary_attachments=False):
@@ -662,7 +623,6 @@ def _run_tests(cmd, until_failure,
                 return 1
             return load.load((None, None), in_streams=run_procs,
                              subunit_out=subunit_out,
-                             repo_type=repo_type,
                              repo_url=repo_url, run_id=combine_id,
                              pretty_out=pretty_out, color=color, stdout=stdout,
                              abbreviate=abbreviate,
@@ -679,7 +639,7 @@ def _run_tests(cmd, until_failure,
                 # the result from the repository because load() returns 0
                 # always on subunit output
                 if subunit_out:
-                    repo = util.get_repo_open(repo_type, repo_url)
+                    repo = util.get_repo_open(repo_url=repo_url)
                     summary = testtools.StreamSummary()
                     last_run = repo.get_latest_run().get_subunit_stream()
                     stream = subunit.ByteStreamToStreamResult(last_run)
