@@ -9,9 +9,9 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from __future__ import print_function
 
 import contextlib
+import random
 import re
 import sys
 
@@ -50,7 +50,7 @@ def filter_tests(filters, test_ids):
 
 
 def exclusion_reader(exclude_list):
-    with contextlib.closing(open(exclude_list, 'r')) as exclude_file:
+    with contextlib.closing(open(exclude_list)) as exclude_file:
         regex_comment_lst = []  # tuple of (regex_compiled, msg, skipped_lst)
         for line in exclude_file:
             raw_line = line.strip()
@@ -89,26 +89,23 @@ def _get_regex_from_include_list(file_path):
     return lines
 
 
-def construct_list(test_ids, blacklist_file=None, whitelist_file=None,
-                   regexes=None, black_regex=None, exclude_list=None,
-                   include_list=None, exclude_regex=None):
+def construct_list(test_ids, regexes=None, exclude_list=None,
+                   include_list=None, exclude_regex=None, randomize=False):
     """Filters the discovered test cases
 
     :param list test_ids: The set of test_ids to be filtered
-    :param str blacklist_file: Soon to be replaced by exclude_list
-    :param str whitelist_file: Soon to be replaced by include_list
     :param list regexes: A list of regex filters to apply to the test_ids. The
         output will contain any test_ids which have a re.search() match for any
         of the regexes in this list. If this is None all test_ids will be
         returned
-    :param str black_regex: Soon to be replaced by exclude_regex
     :param str exclude_list: The path to an exclusion_list file
     :param str include_list: The path to an inclusion_list file
     :param str exclude_regex: regex pattern to exclude tests
+    :param str randomize: Randomize the result
 
     :return: iterable of strings. The strings are full
         test_ids
-    :rtype: set
+    :rtype: list
     """
 
     if not regexes:
@@ -117,8 +114,6 @@ def construct_list(test_ids, blacklist_file=None, whitelist_file=None,
     safe_re = None
     if include_list:
         safe_re = _get_regex_from_include_list(include_list)
-    elif whitelist_file:
-        safe_re = _get_regex_from_include_list(whitelist_file)
 
     if not regexes and safe_re:
         regexes = safe_re
@@ -127,8 +122,6 @@ def construct_list(test_ids, blacklist_file=None, whitelist_file=None,
 
     if exclude_list:
         exclude_data = exclusion_reader(exclude_list)
-    elif blacklist_file:
-        exclude_data = exclusion_reader(blacklist_file)
     else:
         exclude_data = None
 
@@ -144,34 +137,18 @@ def construct_list(test_ids, blacklist_file=None, whitelist_file=None,
             exclude_data.append(record)
         else:
             exclude_data = [record]
-    elif black_regex:
-        msg = "Skipped because of regexp provided as a command line argument:"
-        try:
-            record = (re.compile(black_regex), msg, [])
-        except re.error:
-            print("Invalid regex: %s used for black_regex" % black_regex,
-                  file=sys.stderr)
-            sys.exit(5)
-        if exclude_data:
-            exclude_data.append(record)
-        else:
-            exclude_data = [record]
 
     list_of_test_cases = filter_tests(regexes, test_ids)
-    set_of_test_cases = set(list_of_test_cases)
 
-    if not exclude_data:
-        return set_of_test_cases
+    if exclude_data:
+        # NOTE(afazekas): We might use a faster logic when the
+        # print option is not requested
+        for (rex, msg, s_list) in exclude_data:
+            # NOTE(mtreinish): In the case of overlapping regex the test case
+            # might have already been removed from the set of tests
+            list_of_test_cases = [tc for tc in list_of_test_cases
+                                  if not rex.search(tc)]
+    if randomize:
+        random.shuffle(list_of_test_cases)
 
-    # NOTE(afazekas): We might use a faster logic when the
-    # print option is not requested
-    for (rex, msg, s_list) in exclude_data:
-        for test_case in list_of_test_cases:
-            if rex.search(test_case):
-                # NOTE(mtreinish): In the case of overlapping regex the test
-                # case might have already been removed from the set of tests
-                if test_case in set_of_test_cases:
-                    set_of_test_cases.remove(test_case)
-                    s_list.append(test_case)
-
-    return set_of_test_cases
+    return list_of_test_cases
